@@ -64,11 +64,12 @@ type InputConfig struct {
 	CollectionOffset time.Duration
 	Precision        time.Duration
 
-	NameOverride      string
-	MeasurementPrefix string
-	MeasurementSuffix string
-	Tags              map[string]string
-	Filter            Filter
+	NameOverride           string
+	MeasurementPrefix      string
+	MeasurementSuffix      string
+	Tags                   map[string]string
+	Filter                 Filter
+	AlwaysIncludeLocalTags bool
 }
 
 func (r *RunningInput) metricFiltered(metric telegraf.Metric) {
@@ -97,17 +98,25 @@ func (r *RunningInput) ID() string {
 }
 
 func (r *RunningInput) MakeMetric(metric telegraf.Metric) telegraf.Metric {
-	if ok := r.Config.Filter.Select(metric); !ok {
+	ok, err := r.Config.Filter.Select(metric)
+	if err != nil {
+		r.log.Errorf("filtering failed: %v", err)
+	} else if !ok {
 		r.metricFiltered(metric)
 		return nil
 	}
 
+	tags := r.Config.Tags
+	if r.Config.AlwaysIncludeLocalTags {
+		tags = nil
+	}
+
 	m := makemetric(
 		metric,
 		r.Config.NameOverride,
 		r.Config.MeasurementPrefix,
 		r.Config.MeasurementSuffix,
-		r.Config.Tags,
+		tags,
 		r.defaultTags)
 
 	r.Config.Filter.Modify(metric)
@@ -116,6 +125,15 @@ func (r *RunningInput) MakeMetric(metric telegraf.Metric) telegraf.Metric {
 		return nil
 	}
 
+	if r.Config.AlwaysIncludeLocalTags {
+		// Apply plugin tags after filtering
+		for k, v := range r.Config.Tags {
+			if _, ok := metric.GetTag(k); !ok {
+				metric.AddTag(k, v)
+			}
+		}
+	}
+
 	r.MetricsGathered.Incr(1)
 	GlobalMetricsGathered.Incr(1)
 	return m
