@@ -46,10 +46,8 @@ func (marc *mockAzureResourcesClient) List(_ context.Context, _ *armresources.Cl
 	}
 
 	response := &armresources.ClientListResponse{
-		ClientListResult: armresources.ClientListResult{
-			ResourceListResult: armresources.ResourceListResult{
-				Value: genericResourcesExpanded,
-			},
+		ResourceListResult: armresources.ResourceListResult{
+			Value: genericResourcesExpanded,
 		},
 	}
 
@@ -75,12 +73,10 @@ func (marc *mockAzureResourcesClient) ListByResourceGroup(
 
 	if resourceGroup == "resourceGroup1" {
 		response := &armresources.ClientListByResourceGroupResponse{
-			ClientListByResourceGroupResult: armresources.ClientListByResourceGroupResult{
-				ResourceListResult: armresources.ResourceListResult{
-					Value: []*armresources.GenericResourceExpanded{
-						genericResourcesExpanded[0],
-						genericResourcesExpanded[1],
-					},
+			ResourceListResult: armresources.ResourceListResult{
+				Value: []*armresources.GenericResourceExpanded{
+					genericResourcesExpanded[0],
+					genericResourcesExpanded[1],
 				},
 			},
 		}
@@ -91,11 +87,9 @@ func (marc *mockAzureResourcesClient) ListByResourceGroup(
 
 	if resourceGroup == "resourceGroup2" {
 		response := &armresources.ClientListByResourceGroupResponse{
-			ClientListByResourceGroupResult: armresources.ClientListByResourceGroupResult{
-				ResourceListResult: armresources.ResourceListResult{
-					Value: []*armresources.GenericResourceExpanded{
-						genericResourcesExpanded[2],
-					},
+			ResourceListResult: armresources.ResourceListResult{
+				Value: []*armresources.GenericResourceExpanded{
+					genericResourcesExpanded[2],
 				},
 			},
 		}
@@ -123,30 +117,24 @@ func (mamdc *mockAzureMetricDefinitionsClient) List(
 
 	if resourceID == "/subscriptions/subscriptionID/resourceGroups/resourceGroup1/providers/Microsoft.Test/type1/resource1" {
 		return armmonitor.MetricDefinitionsClientListResponse{
-			MetricDefinitionsClientListResult: armmonitor.MetricDefinitionsClientListResult{
-				MetricDefinitionCollection: armmonitor.MetricDefinitionCollection{
-					Value: metricDefinitions[0],
-				},
+			MetricDefinitionCollection: armmonitor.MetricDefinitionCollection{
+				Value: metricDefinitions[0],
 			},
 		}, nil
 	}
 
 	if resourceID == "/subscriptions/subscriptionID/resourceGroups/resourceGroup1/providers/Microsoft.Test/type2/resource2" {
 		return armmonitor.MetricDefinitionsClientListResponse{
-			MetricDefinitionsClientListResult: armmonitor.MetricDefinitionsClientListResult{
-				MetricDefinitionCollection: armmonitor.MetricDefinitionCollection{
-					Value: metricDefinitions[1],
-				},
+			MetricDefinitionCollection: armmonitor.MetricDefinitionCollection{
+				Value: metricDefinitions[1],
 			},
 		}, nil
 	}
 
 	if resourceID == "/subscriptions/subscriptionID/resourceGroups/resourceGroup2/providers/Microsoft.Test/type1/resource3" {
 		return armmonitor.MetricDefinitionsClientListResponse{
-			MetricDefinitionsClientListResult: armmonitor.MetricDefinitionsClientListResult{
-				MetricDefinitionCollection: armmonitor.MetricDefinitionCollection{
-					Value: metricDefinitions[2],
-				},
+			MetricDefinitionCollection: armmonitor.MetricDefinitionCollection{
+				Value: metricDefinitions[2],
 			},
 		}, nil
 	}
@@ -170,49 +158,37 @@ func (mamc *mockAzureMetricsClient) List(
 
 	if resourceID == "/subscriptions/subscriptionID/resourceGroups/resourceGroup1/providers/Microsoft.Test/type1/resource1" {
 		return armmonitor.MetricsClientListResponse{
-			MetricsClientListResult: armmonitor.MetricsClientListResult{
-				Response: metricResponses[0],
-			},
+			Response: metricResponses[0],
 		}, nil
 	}
 
 	if resourceID == "/subscriptions/subscriptionID/resourceGroups/resourceGroup1/providers/Microsoft.Test/type2/resource2" {
 		return armmonitor.MetricsClientListResponse{
-			MetricsClientListResult: armmonitor.MetricsClientListResult{
-				Response: metricResponses[1],
-			},
+			Response: metricResponses[1],
 		}, nil
 	}
 
 	if resourceID == "/subscriptions/subscriptionID/resourceGroups/resourceGroup2/providers/Microsoft.Test/type1/resource3" {
 		return armmonitor.MetricsClientListResponse{
-			MetricsClientListResult: armmonitor.MetricsClientListResult{
-				Response: metricResponses[2],
-			},
+			Response: metricResponses[2],
 		}, nil
 	}
 
 	if resourceID == "/subscriptions/subscriptionID/resourceGroups/resourceGroup2/providers/Microsoft.Test/type2/resource4" {
 		return armmonitor.MetricsClientListResponse{
-			MetricsClientListResult: armmonitor.MetricsClientListResult{
-				Response: metricResponses[3],
-			},
+			Response: metricResponses[3],
 		}, nil
 	}
 
 	if resourceID == "/subscriptions/subscriptionID/resourceGroups/resourceGroup2/providers/Microsoft.Test/type2/resource5" {
 		return armmonitor.MetricsClientListResponse{
-			MetricsClientListResult: armmonitor.MetricsClientListResult{
-				Response: metricResponses[4],
-			},
+			Response: metricResponses[4],
 		}, nil
 	}
 
 	if resourceID == "/subscriptions/subscriptionID/resourceGroups/resourceGroup2/providers/Microsoft.Test/type2/resource6" {
 		return armmonitor.MetricsClientListResponse{
-			MetricsClientListResult: armmonitor.MetricsClientListResult{
-				Response: metricResponses[5],
-			},
+			Response: metricResponses[5],
 		}, nil
 	}
 
