@@ -2,11 +2,9 @@ package procstat
 
 import (
 	"fmt"
+	"os/user"
 	"testing"
 
-	"os/user"
-
-	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 )
 
@@ -19,7 +17,7 @@ func TestGather_RealPatternIntegration(t *testing.T) {
 	pids, err := pg.Pattern(`procstat`)
 	require.NoError(t, err)
 	fmt.Println(pids)
-	assert.Equal(t, len(pids) > 0, true)
+	require.Equal(t, len(pids) > 0, true)
 }
 
 func TestGather_RealFullPatternIntegration(t *testing.T) {
@@ -31,19 +29,19 @@ func TestGather_RealFullPatternIntegration(t *testing.T) {
 	pids, err := pg.FullPattern(`%procstat%`)
 	require.NoError(t, err)
 	fmt.Println(pids)
-	assert.Equal(t, len(pids) > 0, true)
+	require.Equal(t, len(pids) > 0, true)
 }
 
 func TestGather_RealUserIntegration(t *testing.T) {
 	if testing.Short() {
 		t.Skip("Skipping integration test in short mode")
 	}
-	user, err := user.Current()
+	currentUser, err := user.Current()
 	require.NoError(t, err)
 	pg, err := NewNativeFinder()
 	require.NoError(t, err)
-	pids, err := pg.UID(user.Username)
+	pids, err := pg.UID(currentUser.Username)
 	require.NoError(t, err)
 	fmt.Println(pids)
-	assert.Equal(t, len(pids) > 0, true)
+	require.Equal(t, len(pids) > 0, true)
 }
