@@ -5,6 +5,7 @@ import (
 	"encoding/json"
 	"errors"
 	"fmt"
+	"io"
 	"net"
 	"os"
 	"path/filepath"
@@ -157,10 +158,17 @@ func TestSocketListener(t *testing.T) {
 			require.NoError(t, plugin.Start(&acc))
 			defer plugin.Stop()
 
-			// Setup the client for submitting data
 			addr := plugin.listener.addr()
+
+			// Create a noop client
+			// Server is async, so verify no errors at the end.
 			client, err := createClient(plugin.ServiceAddress, addr, tlsCfg)
 			require.NoError(t, err)
+			require.NoError(t, client.Close())
+
+			// Setup the client for submitting data
+			client, err = createClient(plugin.ServiceAddress, addr, tlsCfg)
+			require.NoError(t, err)
 
 			// Send the data with the correct encoding
 			encoder, err := internal.NewContentEncoder(tt.encoding)
@@ -186,8 +194,10 @@ func TestSocketListener(t *testing.T) {
 }
 
 func TestSocketListenerStream(t *testing.T) {
+	logger := &testutil.CaptureLogger{}
+
 	plugin := &SocketListener{
-		Log:            testutil.Logger{},
+		Log:            logger,
 		ServiceAddress: "tcp://127.0.0.1:0",
 		ReadBufferSize: 1024,
 	}
@@ -223,6 +233,17 @@ func TestSocketListenerStream(t *testing.T) {
 	conns := len(listener.connections)
 	listener.Unlock()
 	require.NotZero(t, conns)
+
+	plugin.Stop()
+
+	// Verify that plugin.Stop() closed the client's connection
+	_ = client.SetReadDeadline(time.Now().Add(time.Second))
+	buf := []byte{1}
+	_, err = client.Read(buf)
+	require.Equal(t, err, io.EOF)
+
+	require.Empty(t, logger.Errors())
+	require.Empty(t, logger.Warnings())
 }
 
 func TestCases(t *testing.T) {
