@@ -2,15 +2,21 @@ package graphite
 
 import (
 	"bufio"
+	"encoding/json"
+	"fmt"
+	"io"
 	"net"
+	"net/http"
 	"net/textproto"
 	"sync"
 	"testing"
 	"time"
 
 	"github.com/stretchr/testify/require"
+	"github.com/testcontainers/testcontainers-go/wait"
 
 	"github.com/influxdata/telegraf"
+	"github.com/influxdata/telegraf/config"
 	"github.com/influxdata/telegraf/metric"
 	"github.com/influxdata/telegraf/testutil"
 )
@@ -22,6 +28,8 @@ func TestGraphiteError(t *testing.T) {
 		Prefix:  "my.prefix",
 		Log:     testutil.Logger{},
 	}
+	require.NoError(t, g.Init())
+
 	// Init metrics
 	m1 := metric.New(
 		"mymeasurement",
@@ -30,14 +38,12 @@ func TestGraphiteError(t *testing.T) {
 		time.Date(2010, time.November, 10, 23, 0, 0, 0, time.UTC),
 	)
 	// Prepare point list
-	var metrics []telegraf.Metric
-	metrics = append(metrics, m1)
-	// Error
-	err1 := g.Connect()
-	require.NoError(t, err1)
-	err2 := g.Write(metrics)
-	require.Error(t, err2)
-	require.Equal(t, "could not write to any Graphite server in cluster", err2.Error())
+	metrics := []telegraf.Metric{m1}
+
+	require.NoError(t, g.Connect())
+	err := g.Write(metrics)
+	require.Error(t, err)
+	require.ErrorIs(t, err, ErrNotConnected)
 }
 
 func TestGraphiteReconnect(t *testing.T) {
@@ -56,6 +62,7 @@ func TestGraphiteReconnect(t *testing.T) {
 		Log:                 testutil.Logger{},
 		GraphiteStrictRegex: `[^a-zA-Z0-9-:._=|\p{L}]`,
 	}
+	require.NoError(t, g.Init())
 
 	t.Log("Writing metric, without any server up, expected to fail")
 	require.NoError(t, g.Connect())
@@ -98,6 +105,7 @@ func TestGraphiteOK(t *testing.T) {
 		Servers: []string{"localhost:12003"},
 		Log:     testutil.Logger{},
 	}
+	require.NoError(t, g.Init())
 
 	// Init metrics
 	m1 := metric.New(
@@ -179,6 +187,7 @@ func TestGraphiteStrictRegex(t *testing.T) {
 		Log:                 testutil.Logger{},
 		GraphiteStrictRegex: `[^a-zA-Z0-9-:._=|\p{L}]`,
 	}
+	require.NoError(t, g.Init())
 	require.NoError(t, g.Connect())
 	require.NoError(t, g.Write([]telegraf.Metric{m}))
 
@@ -200,6 +209,7 @@ func TestGraphiteOkWithSeparatorDot(t *testing.T) {
 		Servers:           []string{"localhost:12003"},
 		Log:               testutil.Logger{},
 	}
+	require.NoError(t, g.Init())
 
 	// Init metrics
 	m1 := metric.New(
@@ -263,6 +273,7 @@ func TestGraphiteOkWithSeparatorUnderscore(t *testing.T) {
 		Servers:           []string{"localhost:12003"},
 		Log:               testutil.Logger{},
 	}
+	require.NoError(t, g.Init())
 
 	// Init metrics
 	m1 := metric.New(
@@ -330,6 +341,7 @@ func TestGraphiteOKWithMultipleTemplates(t *testing.T) {
 		Servers: []string{"localhost:12003"},
 		Log:     testutil.Logger{},
 	}
+	require.NoError(t, g.Init())
 
 	// Init metrics
 	m1 := metric.New(
@@ -393,6 +405,7 @@ func TestGraphiteOkWithTags(t *testing.T) {
 		Servers:            []string{"localhost:12003"},
 		Log:                testutil.Logger{},
 	}
+	require.NoError(t, g.Init())
 
 	// Init metrics
 	m1 := metric.New(
@@ -457,6 +470,7 @@ func TestGraphiteOkWithTagsAndSeparatorDot(t *testing.T) {
 		Servers:            []string{"localhost:12003"},
 		Log:                testutil.Logger{},
 	}
+	require.NoError(t, g.Init())
 
 	// Init metrics
 	m1 := metric.New(
@@ -521,6 +535,7 @@ func TestGraphiteOkWithTagsAndSeparatorUnderscore(t *testing.T) {
 		Servers:            []string{"localhost:12003"},
 		Log:                testutil.Logger{},
 	}
+	require.NoError(t, g.Init())
 
 	// Init metrics
 	m1 := metric.New(
@@ -570,6 +585,95 @@ func TestGraphiteOkWithTagsAndSeparatorUnderscore(t *testing.T) {
 	require.NoError(t, err)
 }
 
+func TestIntegration(t *testing.T) {
+	if testing.Short() {
+		t.Skip("Skipping integration test in short mode")
+	}
+	container := testutil.Container{
+		Image:        "graphiteapp/graphite-statsd",
+		ExposedPorts: []string{"8080", "2003", "2004"},
+		WaitingFor: wait.ForAll(
+			wait.ForListeningPort("8080"),
+			wait.ForListeningPort("2003"),
+			wait.ForListeningPort("2004"),
+			wait.ForLog("run: statsd:"),
+		),
+	}
+	require.NoError(t, container.Start(), "failed to start container")
+	defer container.Terminate()
+
+	// Init plugin
+	plugin := Graphite{
+		Servers:  []string{container.Address + ":" + container.Ports["2003"]},
+		Template: "measurement.tags.field",
+		Timeout:  config.Duration(2 * time.Second),
+		Log:      testutil.Logger{},
+	}
+	require.NoError(t, plugin.Init())
+	require.NoError(t, plugin.Connect())
+	defer plugin.Close()
+
+	metrics := []telegraf.Metric{
+		metric.New(
+			"test",
+			map[string]string{"source": "foo"},
+			map[string]interface{}{"value": 42.0},
+			time.Now(),
+		),
+		metric.New(
+			"test",
+			map[string]string{"source": "bar"},
+			map[string]interface{}{"value": 23.0},
+			time.Now(),
+		),
+	}
+
+	// Verify that we can successfully write data
+	require.NoError(t, plugin.Write(metrics))
+
+	// Wait for the data to settle and check if we got the metrics
+	url := fmt.Sprintf("http://%s:%s/metrics/index.json", container.Address, container.Ports["8080"])
+	require.Eventually(t, func() bool {
+		var actual []string
+		if err := query(url, &actual); err != nil {
+			t.Logf("encountered error %v", err)
+			return false
+		}
+		var foundFoo, foundBar bool
+		for _, m := range actual {
+			switch m {
+			case "test.bar":
+				foundBar = true
+			case "test.foo":
+				foundFoo = true
+			default:
+				continue
+			}
+			if foundBar && foundFoo {
+				return true
+			}
+		}
+		return false
+	}, 10*time.Second, 100*time.Millisecond)
+}
+
+func query(url string, data interface{}) error {
+	//nolint:gosec // Parameters are fixed in the above call
+	resp, err := http.Get(url)
+	if err != nil {
+		fmt.Println("response:", resp)
+		return err
+	}
+	raw, err := io.ReadAll(resp.Body)
+	if err != nil {
+		fmt.Println("raw:", string(raw))
+		return err
+	}
+	resp.Body.Close()
+
+	return json.Unmarshal(raw, &data)
+}
+
 func TCPServer1(t *testing.T, wg *sync.WaitGroup) {
 	tcpServer, err := net.Listen("tcp", "127.0.0.1:12003")
 	require.NoError(t, err)
